import warnings

warnings.warn(
    "The module 'yamcs.mdb.model' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.mdb.model import (  # noqa
    Algorithm,
    Argument,
    ArgumentType,
    ArrayType,
    Command,
    Container,
    DataEncoding,
    EnumValue,
    Member,
    MissionDatabaseItem,
    Parameter,
    ParameterType,
    RangeSet,
    Significance,
    SpaceSystem,
)



import datetime
import threading
from typing import TYPE_CHECKING, Any, Callable, Dict, List, Mapping, Optional

from yamcs.client.core.helpers import parse_server_time
from yamcs.protobuf.filetransfer import filetransfer_pb2

if TYPE_CHECKING:
    from yamcs.client.filetransfer.client import (
        FileListSubscription,
        FileTransferServiceClient,
        TransferSubscription,
    )

__all__ = [
    "EntityInfo",
    "FileTransferCapabilities",
    "FileTransferOption",
    "FileTransferService",
    "RemoteFile",
    "RemoteFileListing",
    "Transfer",
]


class FileTransferService:
    def __init__(self, proto, service_client: "FileTransferServiceClient"):
        self._proto = proto
        self._service_client = service_client
        self._local_entities = [EntityInfo(entity) for entity in proto.localEntities]
        self._remote_entities = [EntityInfo(entity) for entity in proto.remoteEntities]
        self._capabilities = FileTransferCapabilities(proto.capabilities)
        self._transfer_options = [
            FileTransferOption(option) for option in proto.transferOptions
        ]

    @property
    def instance(self) -> str:
        """Instance of the service"""
        return self._proto.instance

    @property
    def name(self) -> str:
        """Name of this service."""
        return self._proto.name

    @property
    def local_entities(self) -> List["EntityInfo"]:
        """List of local entities"""
        return self._local_entities

    @property
    def remote_entities(self) -> List["EntityInfo"]:
        """List of remote entities"""
        return self._remote_entities

    @property
    def capabilities(self) -> "FileTransferCapabilities":
        """Transfer capabilities"""
        return self._capabilities

    @property
    def transfer_options(self) -> List["FileTransferOption"]:
        """List of possible transfer options"""
        return self._transfer_options

    def upload(
        self,
        bucket_name: str,
        object_name: str,
        remote_path: str,
        source_entity: Optional[str] = None,
        destination_entity: Optional[str] = None,
        options: Optional[Mapping[str, Any]] = None,
    ) -> "Transfer":
        """
        Uploads a file located in a bucket to a remote destination path.

        :param bucket_name:
            Name of the bucket containing the source object.
        :param object_name:
            Name of the source object.
        :param remote_path:
            Remote destination.
        :param source_entity:
            Use a specific source entity. (useful in case of multiples)
        :param destination_entity:
            Use a specific destination entity. (useful in case of multiples)
        :param options:
            file transfer options
        """
        return self._service_client.upload(
            bucket_name=bucket_name,
            object_name=object_name,
            remote_path=remote_path,
            source_entity=source_entity,
            destination_entity=destination_entity,
            options=options,
        )

    def download(
        self,
        bucket_name: str,
        remote_path: str,
        object_name: Optional[str] = None,
        source_entity: Optional[str] = None,
        destination_entity: Optional[str] = None,
        options: Optional[Mapping[str, Any]] = None,
    ) -> "Transfer":
        """
        Downloads a file from the source to a bucket.

        :param bucket_name:
            Name of the bucket to receive the file.
        :param object_name:
            Name of the file received in the bucket.
        :param remote_path:
            Name of the file to be downloaded from the source.
        :param source_entity:
            Use a specific source entity. (useful in case of multiples)
        :param destination_entity:
            Use a specific destination entity. (useful in case of multiples)
        :param options:
            File transfer options.
        """
        return self._service_client.download(
            bucket_name=bucket_name,
            remote_path=remote_path,
            object_name=object_name,
            source_entity=source_entity,
            destination_entity=destination_entity,
            options=options,
        )

    def fetch_filelist(
        self,
        remote_path: str,
        source_entity: Optional[str] = None,
        destination_entity: Optional[str] = None,
        options: Optional[Mapping[str, Any]] = None,
    ):
        """
        Sends a request to fetch the directory listing from the remote (destination).

        :param remote_path:
            path on the remote destination to get the file list
        :param source_entity:
            source entity requesting the file list
        :param destination_entity:
            destination entity from which the file list is needed
        :param options:
            option dictionary
        """
        self._service_client.fetch_filelist(
            remote_path=remote_path,
            source_entity=source_entity,
            destination_entity=destination_entity,
            options=options,
        )

    def get_filelist(
        self,
        remote_path: str,
        source_entity: Optional[str] = None,
        destination_entity: Optional[str] = None,
        options: Optional[Mapping[str, Any]] = None,
    ) -> "RemoteFileListing":
        """
        Returns the latest directory listing for the given destination.

        :param remote_path:
            path on the remote destination to get the file list
        :param source_entity:
            source entity requesting the file list
        :param destination_entity:
            destination entity from which the file list is needed
        :param options:
            option dictionary
        """
        return self._service_client.get_filelist(
            remote_path=remote_path,
            source_entity=source_entity,
            destination_entity=destination_entity,
            options=options,
        )

    def pause_transfer(self, id: str) -> None:
        """
        Pauses a transfer
        """
        self._service_client.pause_transfer(id)

    def resume_transfer(self, id: str) -> None:
        """
        Resume a transfer
        """
        self._service_client.resume_transfer(id)

    def cancel_transfer(self, id: str) -> None:
        """
        Cancel a transfer
        """
        self._service_client.cancel_transfer(id)

    def run_file_action(
        self,
        file: str,
        action: str,
        message: Optional[Mapping[str, Any]] = None,
    ) -> Dict[str, Any]:
        """
        Run an action on a remote file.

        Available actions depend on the specific file transfer implementation that
        is in use use.

        .. versionadded:: 1.9.6

        :param file:
            Remote file identifier
        :param action:
            Action identifier
        :param message:
            Action message
        :return:
            Action result (if the action returns anything)
        """
        return self._service_client.run_file_action(file, action, message)

    def create_transfer_subscription(
        self,
        on_data: Optional[Callable[["Transfer"], None]] = None,
        timeout: float = 60,
    ) -> "TransferSubscription":
        """
        Create a new transfer subscription.

        :param on_data:
            Function that gets called with :class:`.Transfer` updates.
        :param timeout:
            The amount of seconds to wait for the request to complete.
        :return:
            Future that can be used to manage the background websocket
            subscription
        :rtype: yamcs.client.filetransfer.client.TransferSubscription
        """
        return self._service_client.create_transfer_subscription(
            on_data=on_data, timeout=timeout
        )

    def create_filelist_subscription(
        self,
        on_data: Optional[Callable[["RemoteFileListing"], None]] = None,
        timeout: float = 60,
    ) -> "FileListSubscription":
        """
        Create a new filelist subscription.

        :param on_data:
            Function that gets called with :class:`.RemoteFileListing` updates.
        :param timeout:
            The amount of seconds to wait for the request to complete.
        :return:
            Future that can be used to manage the background websocket
            subscription
        :rtype: yamcs.client.filetransfer.client.FileListSubscription
        """
        return self._service_client.create_filelist_subscription(
            on_data=on_data, timeout=timeout
        )

    def __str__(self):
        return self.name


class EntityInfo:
    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Name of the entity"""
        return self._proto.name

    @property
    def id(self) -> str:
        """Entity ID"""
        return self._proto.id


class FileTransferCapabilities:
    def __init__(self, proto):
        self._proto = proto

    @property
    def upload(self) -> bool:
        return self._proto.upload

    @property
    def download(self) -> bool:
        return self._proto.download

    @property
    def remote_path(self) -> bool:
        return self._proto.remotePath

    @property
    def filelist(self) -> bool:
        return self._proto.fileList

    @property
    def has_transfer_type(self) -> bool:
        return self._proto.has_transfer_type

    @property
    def pause_resume(self) -> bool:
        return self._proto.pauseResume

    def __str__(self):
        return str(self._proto)


class FileTransferOption:

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Name of the option"""
        return self._proto.name

    @property
    def type(self) -> str:
        """Type of the option"""
        return filetransfer_pb2.FileTransferOption.Type.Name(self._proto.type)

    @property
    def description(self) -> str:
        """Description for the option"""
        return self._proto.description

    @property
    def associated_text(self) -> str:
        """Text associated with the option"""
        return self._proto.associatedText

    @property
    def default(self) -> Any:
        """Default value for the option"""
        return self._proto.default

    @property
    def values(self):
        """List of possible values for the option"""
        return [
            {"value": item.value, "verbose_name": item.verboseName}
            for item in self._proto.values
        ]

    @property
    def allow_custom_option(self) -> bool:
        """Whether using different values from the pre-set ones is allowed"""
        return self._proto.allowCustomOption

    def __str__(self):
        return str(self._proto)


class Transfer:
    """
    Represents a file transfer.
    """

    def __init__(self, proto, service_client):
        self._proto = proto
        self._service_client = service_client

    @property
    def id(self) -> str:
        """Yamcs-local transfer identifier."""
        return self._proto.id

    @property
    def bucket(self) -> str:
        return self._proto.bucket

    @property
    def object_name(self) -> str:
        return self._proto.objectName

    @property
    def remote_path(self) -> str:
        return self._proto.remotePath

    @property
    def time(self) -> Optional[datetime.datetime]:
        """Time when the transfer was started."""
        if self._proto.HasField("startTime"):
            return parse_server_time(self._proto.startTime)
        return None

    @property
    def reliable(self) -> bool:
        """True if this is a Class 2 CFDP transfer."""
        return self._proto.reliable

    @property
    def state(self) -> Optional[str]:
        """Current transfer state."""
        if self._proto.HasField("state"):
            return filetransfer_pb2.TransferState.Name(self._proto.state)
        return None

    @property
    def size(self) -> int:
        """Total bytes to transfer."""
        return self._proto.totalSize

    @property
    def transferred_size(self) -> int:
        """Total bytes already transferred."""
        return self._proto.sizeTransferred

    def is_complete(self) -> bool:
        """
        Returns whether this transfer is complete. A transfer
        can be completed, yet still failed.
        """
        return self.state == "FAILED" or self.state == "COMPLETED"

    def is_success(self) -> bool:
        """
        Returns true if this transfer was completed successfully.
        """
        return self.state == "COMPLETED"

    @property
    def error(self) -> Optional[str]:
        """
        Error message in case the transfer failed.
        """
        if self.state == "FAILED" and self._proto.HasField("failureReason"):
            return self._proto.failureReason
        return None

    def pause(self):
        """
        Pause this transfer
        """
        self._service_client.pause_transfer(self.id)

    def resume(self):
        """
        Resume this transfer
        """
        self._service_client.resume_transfer(self.id)

    def cancel(self):
        """
        Cancel this transfer
        """
        self._service_client.cancel_transfer(self.id)

    def await_complete(self, timeout: Optional[float] = None):
        """
        Wait for the transfer to be completed.

        :param timeout:
            The amount of seconds to wait.
        """
        completed = threading.Event()

        def callback(updated_transfer):
            if updated_transfer.id == self.id:
                self._proto = updated_transfer._proto
                if self.is_complete():
                    completed.set()

        subscription = self._service_client.create_transfer_subscription(
            on_data=callback
        )

        try:
            if not completed.wait(timeout=timeout):
                # Remark that a timeout does *not* mean that the underlying
                # work is canceled.
                raise TimeoutError("Timed out.")
        finally:
            subscription.cancel()


class RemoteFileListing:
    """
    Represents a list of files from a remote.
    """

    def __init__(self, proto):
        self._proto = proto
        self._files = [RemoteFile(file) for file in proto.files]

    @property
    def files(self) -> List["RemoteFile"]:
        """List of files"""
        return self._files

    @property
    def destination(self) -> str:
        """Remote destination of the file list"""
        return self._proto.destination

    @property
    def remote_path(self) -> str:
        """Remote directory of the file list"""
        return self._proto.remotePath

    @property
    def list_time(self) -> datetime.datetime:
        """Time the file list was made"""
        return parse_server_time(self._proto.listTime)


class RemoteFile:
    """
    Represents a file on a remote entity.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Identifying name of the file"""
        return self._proto.name

    @property
    def display_name(self) -> Optional[str]:
        """
        Optionally, a preferred displayed name of the file.
        """
        if self._proto.HasField("displayName"):
            return self._proto.displayName
        return None

    @property
    def is_directory(self) -> bool:
        """Whether the file is a directory"""
        return self._proto.isDirectory

    @property
    def size(self) -> int:
        """File size in bytes"""
        return self._proto.size

    @property
    def modified(self) -> Optional[datetime.datetime]:
        """Latest modification time of the file"""
        if self._proto.HasField("modified"):
            return parse_server_time(self._proto.modified)
        return None



import datetime
from typing import List, Optional

from yamcs.client.core.context import Context
from yamcs.client.core.helpers import to_server_time
from yamcs.client.tco.model import TCOStatus, TofInterval
from yamcs.protobuf.tco import tco_pb2

__all__ = [
    "TCOClient",
]


class TCOClient:
    """
    Client for interacting with a Time Correlation service managed by Yamcs.
    """

    def __init__(self, ctx: Context, instance: str, service: str):
        super(TCOClient, self).__init__()
        self.ctx = ctx
        self._instance = instance
        self._service = service

    def get_status(self) -> TCOStatus:
        """
        Retrieve the TCO status.
        """
        response = self.ctx.get_proto(f"/tco/{self._instance}/{self._service}/status")
        message = tco_pb2.TcoStatus()
        message.ParseFromString(response.content)
        return TCOStatus(message)

    def reconfigure(
        self,
        accuracy: Optional[float] = None,
        validity: Optional[float] = None,
        ob_delay: Optional[float] = None,
        default_tof: Optional[float] = None,
    ):
        """
        Updates one or more TCO options

        :param accuracy:
            Accuracy in seconds.
        :param validity:
            Validity in seconds.
        :param ob_delay:
            Onboard delay in seconds.
        :param default_tof:
            Default ToF in seconds. This value is used if the ToF estimator
            does not find a matching interval.
        """
        req = tco_pb2.TcoConfig()
        if accuracy is not None:
            req.accuracy = accuracy
        if validity is not None:
            req.validity = validity
        if ob_delay is not None:
            req.onboardDelay = ob_delay
        if default_tof is not None:
            req.defaultTof = default_tof

        url = f"/tco/{self._instance}/{self._service}/config"
        self.ctx.post_proto(url, data=req.SerializeToString())  # TODO should be patch

    def add_tof_interval(
        self, start: datetime.datetime, stop: datetime.datetime, polynomial: List[float]
    ):
        """
        Defines a ToF interval for the ERT range ``[start, stop]``, specifying
        a polynomial function of the form: `tof = a + bx + cx^2 + ...` where `x`
        is ERT minus the provided start date.

        :param start:
            ERT start
        :param stop:
            ERT stop
        :param polynomial:
            Coefficients in the order ``[a, b, c, ...]``
        """
        self.add_tof_intervals([TofInterval(start, stop, polynomial)])

    def add_tof_intervals(self, intervals: List[TofInterval]):
        """
        Adds multiple ToF intervals at once.

        :param intervals:
            List of ToF intervals.
        """
        req = tco_pb2.AddTimeOfFlightIntervalsRequest()
        for interval in intervals:
            tof = req.intervals.add()
            tof.ertStart.MergeFrom(to_server_time(interval.start))
            tof.ertStop.MergeFrom(to_server_time(interval.stop))
            tof.polCoef.extend(interval.polynomial)

        url = f"/tco/{self._instance}/{self._service}/tof:addIntervals"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def remove_tof_intervals(self, start: datetime.datetime, stop: datetime.datetime):
        """
        Removes previously registered ToF intervals whose start date
        falls in the specified range ``[start, stop]``.

        :param start:
            ERT start
        :param stop:
            ERT stop
        """
        req = tco_pb2.DeleteTimeOfFlightIntervalsRequest()
        req.start.MergeFrom(to_server_time(start))
        req.stop.MergeFrom(to_server_time(stop))

        url = f"/tco/{self._instance}/{self._service}/tof:deleteIntervals"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def reset_coefficients(self):
        """
        Resets current TCO coefficients, as well as any
        collected samples.
        """
        url = f"/tco/{self._instance}/{self._service}:reset"
        self.ctx.post_proto(url)

    def override_coefficients(
        self, utc: datetime.datetime, obt: int, gradient: float = 0, offset: float = 0
    ):
        """
        Manually override the assocation between UTC and
        onboard time.

        .. note::
            If later on you want to revert to automatically computed
            coefficients, use :meth:`reset_coefficients`.

        :param utc:
            UTC
        :param obt:
            Onboard time
        :param gradient:
            Gradient
        :param offset:
            Offset
        """
        req = tco_pb2.TcoCoefficients()
        req.utc.MergeFrom(to_server_time(utc))
        req.obt = obt
        req.gradient = gradient
        req.offset = offset

        url = f"/tco/{self._instance}/{self._service}/coefficients"
        self.ctx.post_proto(url, data=req.SerializeToString())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/instances/instances_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.instances import instances_pb2 as yamcs_dot_protobuf_dot_instances_dot_instances__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/instances/instances_service.proto',
  package='yamcs.protobuf.instances',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\025InstancesServiceProtoP\001',
  serialized_pb=b'\n0yamcs/protobuf/instances/instances_service.proto\x12\x18yamcs.protobuf.instances\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a(yamcs/protobuf/instances/instances.proto\"&\n\x14ListInstancesRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x03(\t\"S\n\x15ListInstancesResponse\x12:\n\tinstances\x18\x01 \x03(\x0b\x32\'.yamcs.protobuf.instances.YamcsInstance\"\xc1\x02\n\x15\x43reateInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12W\n\x0ctemplateArgs\x18\x03 \x03(\x0b\x32\x41.yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry\x12K\n\x06labels\x18\x04 \x03(\x0b\x32;.yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x1aReconfigureInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\\\n\x0ctemplateArgs\x18\x02 \x03(\x0b\x32\x46.yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry\x12P\n\x06labels\x18\x03 \x03(\x0b\x32@.yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n\x1dListInstanceTemplatesResponse\x12=\n\ttemplates\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.instances.InstanceTemplate\".\n\x1aGetInstanceTemplateRequest\x12\x10\n\x08template\x18\x01 \x01(\t\"&\n\x12GetInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"(\n\x14StartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\'\n\x13StopInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"*\n\x16RestartInstanceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t2\xa3\x0b\n\x0cInstancesApi\x12\x87\x01\n\x15ListInstanceTemplates\x12\x16.google.protobuf.Empty\x1a\x37.yamcs.protobuf.instances.ListInstanceTemplatesResponse\"\x1d\x8a\x92\x03\x19\n\x17/api/instance-templates\x12\xa1\x01\n\x13GetInstanceTemplate\x12\x34.yamcs.protobuf.instances.GetInstanceTemplateRequest\x1a*.yamcs.protobuf.instances.InstanceTemplate\"(\x8a\x92\x03$\n\"/api/instance-templates/{template}\x12\x86\x01\n\rListInstances\x12..yamcs.protobuf.instances.ListInstancesRequest\x1a/.yamcs.protobuf.instances.ListInstancesResponse\"\x14\x8a\x92\x03\x10\n\x0e/api/instances\x12h\n\x12SubscribeInstances\x12\x16.google.protobuf.Empty\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x0f\xda\x92\x03\x0b\n\tinstances0\x01\x12\x85\x01\n\x0bGetInstance\x12,.yamcs.protobuf.instances.GetInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x1f\x8a\x92\x03\x1b\n\x19/api/instances/{instance}\x12\x83\x01\n\x0e\x43reateInstance\x12/.yamcs.protobuf.instances.CreateInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\x17\x8a\x92\x03\x13\x1a\x0e/api/instances:\x01*\x12\xa4\x01\n\x13ReconfigureInstance\x12\x34.yamcs.protobuf.instances.ReconfigureInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\".\x8a\x92\x03*\x1a%/api/instances/{instance}:reconfigure:\x01*\x12\x8f\x01\n\rStartInstance\x12..yamcs.protobuf.instances.StartInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"%\x8a\x92\x03!\x1a\x1f/api/instances/{instance}:start\x12\x8c\x01\n\x0cStopInstance\x12-.yamcs.protobuf.instances.StopInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"$\x8a\x92\x03 \x1a\x1e/api/instances/{instance}:stop\x12\x95\x01\n\x0fRestartInstance\x12\x30.yamcs.protobuf.instances.RestartInstanceRequest\x1a\'.yamcs.protobuf.instances.YamcsInstance\"\'\x8a\x92\x03#\x1a!/api/instances/{instance}:restart\x1a\x04\xd0\x80\x01\x01\x42-\n\x12org.yamcs.protobufB\x15InstancesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_instances_dot_instances__pb2.DESCRIPTOR,])




_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yamcs.protobuf.instances.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.instances.ListInstancesRequest.filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=216,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yamcs.protobuf.instances.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yamcs.protobuf.instances.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=301,
)


_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=578,
)

_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=625,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yamcs.protobuf.instances.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.CreateInstanceRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.CreateInstanceRequest.template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.CreateInstanceRequest.templateArgs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY, _CREATEINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=625,
)


_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=578,
)

_RECONFIGUREINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=625,
)

_RECONFIGUREINSTANCEREQUEST = _descriptor.Descriptor(
  name='ReconfigureInstanceRequest',
  full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.templateArgs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.ReconfigureInstanceRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY, _RECONFIGUREINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=950,
)


_LISTINSTANCETEMPLATESRESPONSE = _descriptor.Descriptor(
  name='ListInstanceTemplatesResponse',
  full_name='yamcs.protobuf.instances.ListInstanceTemplatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templates', full_name='yamcs.protobuf.instances.ListInstanceTemplatesResponse.templates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1046,
)


_GETINSTANCETEMPLATEREQUEST = _descriptor.Descriptor(
  name='GetInstanceTemplateRequest',
  full_name='yamcs.protobuf.instances.GetInstanceTemplateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.GetInstanceTemplateRequest.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1094,
)


_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yamcs.protobuf.instances.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.GetInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1134,
)


_STARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='StartInstanceRequest',
  full_name='yamcs.protobuf.instances.StartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.StartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1176,
)


_STOPINSTANCEREQUEST = _descriptor.Descriptor(
  name='StopInstanceRequest',
  full_name='yamcs.protobuf.instances.StopInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.StopInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1217,
)


_RESTARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='RestartInstanceRequest',
  full_name='yamcs.protobuf.instances.RestartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.instances.RestartInstanceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1261,
)

_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _RECONFIGUREINSTANCEREQUEST
_RECONFIGUREINSTANCEREQUEST_LABELSENTRY.containing_type = _RECONFIGUREINSTANCEREQUEST
_RECONFIGUREINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY
_RECONFIGUREINSTANCEREQUEST.fields_by_name['labels'].message_type = _RECONFIGUREINSTANCEREQUEST_LABELSENTRY
_LISTINSTANCETEMPLATESRESPONSE.fields_by_name['templates'].message_type = yamcs_dot_protobuf_dot_instances_dot_instances__pb2._INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ReconfigureInstanceRequest'] = _RECONFIGUREINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse'] = _LISTINSTANCETEMPLATESRESPONSE
DESCRIPTOR.message_types_by_name['GetInstanceTemplateRequest'] = _GETINSTANCETEMPLATEREQUEST
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceRequest'] = _STARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceRequest'] = _STOPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RestartInstanceRequest'] = _RESTARTINSTANCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESRESPONSE,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), {

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest.TemplateArgsEntry)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.CreateInstanceRequest)
  })
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)

ReconfigureInstanceRequest = _reflection.GeneratedProtocolMessageType('ReconfigureInstanceRequest', (_message.Message,), {

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest.TemplateArgsEntry)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _RECONFIGUREINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ReconfigureInstanceRequest)
  })
_sym_db.RegisterMessage(ReconfigureInstanceRequest)
_sym_db.RegisterMessage(ReconfigureInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(ReconfigureInstanceRequest.LabelsEntry)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCETEMPLATESRESPONSE,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.ListInstanceTemplatesResponse)
  })
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

GetInstanceTemplateRequest = _reflection.GeneratedProtocolMessageType('GetInstanceTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCETEMPLATEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.GetInstanceTemplateRequest)
  })
_sym_db.RegisterMessage(GetInstanceTemplateRequest)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.GetInstanceRequest)
  })
_sym_db.RegisterMessage(GetInstanceRequest)

StartInstanceRequest = _reflection.GeneratedProtocolMessageType('StartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.StartInstanceRequest)
  })
_sym_db.RegisterMessage(StartInstanceRequest)

StopInstanceRequest = _reflection.GeneratedProtocolMessageType('StopInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.StopInstanceRequest)
  })
_sym_db.RegisterMessage(StopInstanceRequest)

RestartInstanceRequest = _reflection.GeneratedProtocolMessageType('RestartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTINSTANCEREQUEST,
  '__module__' : 'yamcs.protobuf.instances.instances_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.RestartInstanceRequest)
  })
_sym_db.RegisterMessage(RestartInstanceRequest)


DESCRIPTOR._options = None
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_CREATEINSTANCEREQUEST_LABELSENTRY._options = None
_RECONFIGUREINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_RECONFIGUREINSTANCEREQUEST_LABELSENTRY._options = None

_INSTANCESAPI = _descriptor.ServiceDescriptor(
  name='InstancesApi',
  full_name='yamcs.protobuf.instances.InstancesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=1264,
  serialized_end=2707,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListInstanceTemplates',
    full_name='yamcs.protobuf.instances.InstancesApi.ListInstanceTemplates',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTINSTANCETEMPLATESRESPONSE,
    serialized_options=b'\212\222\003\031\n\027/api/instance-templates',
  ),
  _descriptor.MethodDescriptor(
    name='GetInstanceTemplate',
    full_name='yamcs.protobuf.instances.InstancesApi.GetInstanceTemplate',
    index=1,
    containing_service=None,
    input_type=_GETINSTANCETEMPLATEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._INSTANCETEMPLATE,
    serialized_options=b'\212\222\003$\n\"/api/instance-templates/{template}',
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yamcs.protobuf.instances.InstancesApi.ListInstances',
    index=2,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    serialized_options=b'\212\222\003\020\n\016/api/instances',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeInstances',
    full_name='yamcs.protobuf.instances.InstancesApi.SubscribeInstances',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\332\222\003\013\n\tinstances',
  ),
  _descriptor.MethodDescriptor(
    name='GetInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.GetInstance',
    index=4,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003\033\n\031/api/instances/{instance}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.CreateInstance',
    index=5,
    containing_service=None,
    input_type=_CREATEINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003\023\032\016/api/instances:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ReconfigureInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.ReconfigureInstance',
    index=6,
    containing_service=None,
    input_type=_RECONFIGUREINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003*\032%/api/instances/{instance}:reconfigure:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='StartInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.StartInstance',
    index=7,
    containing_service=None,
    input_type=_STARTINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003!\032\037/api/instances/{instance}:start',
  ),
  _descriptor.MethodDescriptor(
    name='StopInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.StopInstance',
    index=8,
    containing_service=None,
    input_type=_STOPINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003 \032\036/api/instances/{instance}:stop',
  ),
  _descriptor.MethodDescriptor(
    name='RestartInstance',
    full_name='yamcs.protobuf.instances.InstancesApi.RestartInstance',
    index=9,
    containing_service=None,
    input_type=_RESTARTINSTANCEREQUEST,
    output_type=yamcs_dot_protobuf_dot_instances_dot_instances__pb2._YAMCSINSTANCE,
    serialized_options=b'\212\222\003#\032!/api/instances/{instance}:restart',
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESAPI)

DESCRIPTOR.services_by_name['InstancesApi'] = _INSTANCESAPI

# @@protoc_insertion_point(module_scope)



import functools
import json
from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional

from google.protobuf import json_format, struct_pb2
from yamcs.client.core.context import Context
from yamcs.client.core.exceptions import NotFound
from yamcs.client.core.futures import WebSocketSubscriptionFuture
from yamcs.client.core.subscriptions import WebSocketSubscriptionManager
from yamcs.client.filetransfer.model import (
    FileTransferService,
    RemoteFileListing,
    Transfer,
)
from yamcs.protobuf.filetransfer import filetransfer_pb2

__all__ = [
    "FileListSubscription",
    "FileTransferClient",
    "FileTransferServiceClient",
    "TransferSubscription",
]


def _wrap_callback_parse_transfer_data(subscription, on_data, message):
    """
    Wraps an (optional) user callback to parse TransferInfo
    from a WebSocket data message
    """
    pb = filetransfer_pb2.TransferInfo()
    message.Unpack(pb)
    transfer = subscription._process(pb)
    if on_data:
        on_data(transfer)


def _wrap_callback_parse_filelist_data(subscription, on_data, message):
    """
    Wraps an (optional) user callback to parse ListFilesResponse
    from a WebSocket data message
    """
    pb = filetransfer_pb2.ListFilesResponse()
    message.Unpack(pb)
    filelist = subscription._process(pb)
    if on_data:
        on_data(filelist)


class TransferSubscription(WebSocketSubscriptionFuture):
    """
    Local object providing access to transfer updates.

    A subscription object stores the last transfer info for
    each transfer.
    """

    def __init__(self, manager, service_client: "FileTransferServiceClient"):
        super(TransferSubscription, self).__init__(manager)
        self.service_client = service_client
        self._cache = {}
        """Transfer cache keyed by id."""

    def get_transfer(self, id: str) -> Optional[Transfer]:
        """
        Returns the latest transfer state.

        :param id:
            Transfer identifier
        """
        if id in self._cache:
            return self._cache[id]
        return None

    def list_transfers(self) -> List[Transfer]:
        """
        Returns a snapshot of all transfer info.
        """
        return [self._cache[k] for k in self._cache]

    def list_ongoing(self) -> List[Transfer]:
        """
        Returns all ongoing transfers.
        """
        return [t for t in self.list_transfers() if not t.is_complete()]

    def list_completed(self) -> List[Transfer]:
        """
        Returns all completed transfers (successful or not).
        """
        return [t for t in self.list_transfers() if t.is_complete()]

    def _process(self, proto) -> Transfer:
        if proto.id in self._cache:
            transfer = self._cache[proto.id]
            transfer._proto = proto
        else:
            transfer = Transfer(proto, service_client=self.service_client)
            self._cache[transfer.id] = transfer

        return transfer


class FileListSubscription(WebSocketSubscriptionFuture):
    """
    Local object providing access to filelist updates.

    A subscription object stores the last filelist info for
    each remotepath and destination.
    """

    def __init__(self, manager):
        super(FileListSubscription, self).__init__(manager)
        self._cache = {}
        """Filelist cache keyed by (destination, remotePath)"""

    def get_filelist(
        self, remote_path: str, destination: str
    ) -> Optional[RemoteFileListing]:
        """
        Get the latest cached filelist for the given remote path and destination

        :param remote_path:
            path on the remote destination
        :param destination:
            remote entity name
        """
        return self._cache.get((remote_path, destination))

    def _process(self, proto) -> RemoteFileListing:
        filelist = RemoteFileListing(proto)
        self._cache[(filelist.destination, filelist.remote_path)] = filelist
        return filelist


class FileTransferClient:
    """
    Client for working with file transfers (e.g. CFDP) managed by Yamcs.
    """

    def __init__(self, ctx: Context, instance: str):
        super(FileTransferClient, self).__init__()
        self.ctx = ctx
        self._instance = instance
        self._default_service = None

    def list_services(self) -> Iterable[FileTransferService]:
        """
        List the services.
        """
        # Server does not do pagination on listings of this resource.
        # Return an iterator anyway for similarity with other API methods
        response = self.ctx.get_proto(path=f"/filetransfer/{self._instance}/services")
        message = filetransfer_pb2.ListFileTransferServicesResponse()
        message.ParseFromString(response.content)
        services = getattr(message, "services")
        result = []
        for proto in services:
            service_client = FileTransferServiceClient(self.ctx, proto)
            result.append(FileTransferService(proto, service_client))
        return iter(result)

    def get_service(self, name: str) -> FileTransferService:
        """
        Get a specific File Transfer service.

        :param name:
            The service name.
        """
        # TODO should have an actual server-side operation for this
        for service in self.list_services():
            if service.name == name:
                return service
        raise NotFound()


class FileTransferServiceClient:
    def __init__(self, ctx: Context, proto):
        self.ctx = ctx
        self._instance = proto.instance
        self._service = proto.name

    def upload(
        self,
        bucket_name: str,
        object_name: str,
        remote_path: str,
        source_entity: Optional[str],
        destination_entity: Optional[str],
        options: Optional[Mapping[str, Any]],
    ) -> Transfer:
        req = filetransfer_pb2.CreateTransferRequest()
        req.direction = filetransfer_pb2.TransferDirection.UPLOAD
        req.bucket = bucket_name
        req.objectName = object_name
        req.remotePath = remote_path
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity
        if options:
            req.options.update(options)

        url = f"/filetransfer/{self._instance}/{self._service}/transfers"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        message = filetransfer_pb2.TransferInfo()
        message.ParseFromString(response.content)
        return Transfer(message, self)

    def download(
        self,
        bucket_name: str,
        remote_path: str,
        object_name: Optional[str],
        source_entity: Optional[str],
        destination_entity: Optional[str],
        options: Optional[Mapping[str, Any]],
    ) -> Transfer:
        req = filetransfer_pb2.CreateTransferRequest()
        req.direction = filetransfer_pb2.TransferDirection.DOWNLOAD
        req.bucket = bucket_name
        req.remotePath = remote_path
        if object_name:
            req.objectName = object_name
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity
        if options:
            req.options.update(options)

        url = f"/filetransfer/{self._instance}/{self._service}/transfers"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        message = filetransfer_pb2.TransferInfo()
        message.ParseFromString(response.content)
        return Transfer(message, self)

    def fetch_filelist(
        self,
        remote_path: str,
        source_entity: Optional[str],
        destination_entity: Optional[str],
        options: Optional[Mapping[str, Any]],
    ):
        req = filetransfer_pb2.ListFilesRequest()
        req.remotePath = remote_path
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity
        if options:
            req.options.update(options)
        url = f"/filetransfer/{self._instance}/{self._service}/files:sync"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def get_filelist(
        self,
        remote_path: str,
        source_entity: Optional[str],
        destination_entity: Optional[str],
        options: Optional[Mapping[str, Any]],
    ) -> RemoteFileListing:
        params = {"remotePath": remote_path}
        if source_entity:
            params["source"] = source_entity
        if destination_entity:
            params["destination"] = destination_entity
        if options:
            params["options"] = json.dumps(options)
        url = f"/filetransfer/{self._instance}/{self._service}/files"
        response = self.ctx.get_proto(url, params=params)
        message = filetransfer_pb2.ListFilesResponse()
        message.ParseFromString(response.content)
        return RemoteFileListing(message)

    def pause_transfer(self, id: str) -> None:
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:pause"
        self.ctx.post_proto(url)

    def resume_transfer(self, id: str) -> None:
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:resume"
        self.ctx.post_proto(url)

    def cancel_transfer(self, id: str) -> None:
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:cancel"
        self.ctx.post_proto(url)

    def run_file_action(
        self,
        file: str,
        action: str,
        message: Optional[Mapping[str, Any]] = None,
    ) -> Dict[str, Any]:
        req = filetransfer_pb2.RunFileActionRequest()
        req.file = file
        req.action = action
        if message:
            req.message.update(message)

        url = f"/filetransfer/{self._instance}/{self._service}/files:runFileAction"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        response_message = struct_pb2.Struct()
        response_message.ParseFromString(response.content)
        return json_format.MessageToDict(response_message)

    def create_transfer_subscription(
        self,
        on_data: Optional[Callable[[Transfer], None]] = None,
        timeout: float = 60,
    ) -> TransferSubscription:
        options = filetransfer_pb2.SubscribeTransfersRequest()
        options.instance = self._instance
        options.serviceName = self._service

        manager = WebSocketSubscriptionManager(
            self.ctx, topic="file-transfers", options=options
        )

        # Represent subscription as a future
        subscription = TransferSubscription(manager, self)

        wrapped_callback = functools.partial(
            _wrap_callback_parse_transfer_data, subscription, on_data
        )

        manager.open(wrapped_callback)

        # Wait until a reply or exception is received
        subscription.reply(timeout=timeout)

        return subscription

    def create_filelist_subscription(
        self,
        on_data: Optional[Callable[[RemoteFileListing], None]] = None,
        timeout: float = 60,
    ) -> FileListSubscription:
        options = filetransfer_pb2.SubscribeTransfersRequest()
        options.instance = self._instance
        options.serviceName = self._service

        manager = WebSocketSubscriptionManager(
            self.ctx, topic="remote-file-list", options=options
        )

        # Represent subscription as a future
        subscription = FileListSubscription(manager)

        wrapped_callback = functools.partial(
            _wrap_callback_parse_filelist_data, subscription, on_data
        )

        manager.open(wrapped_callback)

        # Wait until a reply or exception is received
        subscription.reply(timeout=timeout)

        return subscription



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/sdls/sdls.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/sdls/sdls.proto',
  package='yamcs.protobuf.sdls',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\tSdlsProtoP\001',
  serialized_pb=b'\n\x1eyamcs/protobuf/sdls/sdls.proto\x12\x13yamcs.protobuf.sdls\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"w\n\rSetSpiRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08linkName\x18\x02 \x01(\t\x12\x0c\n\x04vcId\x18\x03 \x01(\r\x12\x34\n\x04\x62ody\x18\x04 \x02(\x0b\x32&.yamcs.protobuf.sdls.SetSpiRequestBody\" \n\x11SetSpiRequestBody\x12\x0b\n\x03spi\x18\x01 \x02(\r\"y\n\x0eSetSpisRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08linkName\x18\x02 \x01(\t\x12\x0c\n\x04vcId\x18\x03 \x01(\r\x12\x35\n\x04\x62ody\x18\x04 \x02(\x0b\x32\'.yamcs.protobuf.sdls.SetSpisRequestBody\"\"\n\x12SetSpisRequestBody\x12\x0c\n\x04spis\x18\x01 \x03(\r\"C\n\x10GetSeqCtrRequest\x12\x10\n\x08instance\x18\x01 \x02(\t\x12\x10\n\x08linkName\x18\x02 \x02(\t\x12\x0b\n\x03spi\x18\x03 \x02(\r\" \n\x11GetSeqCtrResponse\x12\x0b\n\x03seq\x18\x01 \x02(\x0c\"8\n\x12GetLinkSpisRequest\x12\x10\n\x08instance\x18\x01 \x02(\t\x12\x10\n\x08linkName\x18\x02 \x02(\t\"#\n\x13GetLinkSpisResponse\x12\x0c\n\x04spis\x18\x01 \x03(\r\"|\n\x10SetSeqCtrRequest\x12\x10\n\x08instance\x18\x01 \x02(\t\x12\x10\n\x08linkName\x18\x02 \x02(\t\x12\x0b\n\x03spi\x18\x03 \x02(\r\x12\x37\n\x04\x62ody\x18\x04 \x02(\x0b\x32).yamcs.protobuf.sdls.SetSeqCtrRequestBody\"#\n\x14SetSeqCtrRequestBody\x12\x0b\n\x03seq\x18\x01 \x02(\x0c\"c\n\rSetKeyRequest\x12\x10\n\x08instance\x18\x01 \x02(\t\x12\x10\n\x08linkName\x18\x02 \x02(\t\x12\x0b\n\x03spi\x18\x03 \x02(\r\x12!\n\x04\x64\x61ta\x18\x04 \x02(\x0b\x32\x13.yamcs.api.HttpBody\"?\n\x0cGetSaRequest\x12\x10\n\x08instance\x18\x01 \x02(\t\x12\x10\n\x08linkName\x18\x02 \x02(\t\x12\x0b\n\x03spi\x18\x03 \x02(\r\"\x86\x01\n\rGetSaResponse\x12\x0b\n\x03seq\x18\x01 \x02(\x0c\x12\x11\n\talgorithm\x18\x02 \x02(\t\x12\x0e\n\x06keyLen\x18\x03 \x02(\r\x12\x16\n\x0esdlsHeaderSize\x18\x04 \x02(\r\x12\x17\n\x0fsdlsTrailerSize\x18\x05 \x02(\r\x12\x14\n\x0csdlsOverhead\x18\x06 \x02(\r2\xd9\x07\n\x07SdlsApi\x12\x96\x01\n\x0bGetLinkSpis\x12\'.yamcs.protobuf.sdls.GetLinkSpisRequest\x1a(.yamcs.protobuf.sdls.GetLinkSpisResponse\"4\x8a\x92\x03\x30\n\x1f/api/sdls/{instance}/{linkName}j\rGet link SPIs\x12\x83\x01\n\x05GetSa\x12!.yamcs.protobuf.sdls.GetSaRequest\x1a\".yamcs.protobuf.sdls.GetSaResponse\"3\x8a\x92\x03/\n%/api/sdls/{instance}/{linkName}/{spi}j\x06Get SA\x12\x8b\x01\n\tGetSeqCtr\x12%.yamcs.protobuf.sdls.GetSeqCtrRequest\x1a&.yamcs.protobuf.sdls.GetSeqCtrResponse\"/\x8a\x92\x03+\n)/api/sdls/{instance}/{linkName}/{spi}/seq\x12\x81\x01\n\tSetSeqCtr\x12%.yamcs.protobuf.sdls.SetSeqCtrRequest\x1a\x16.google.protobuf.Empty\"5\x8a\x92\x03\x31\x12)/api/sdls/{instance}/{linkName}/{spi}/seq:\x04\x62ody\x12{\n\x06SetKey\x12\".yamcs.protobuf.sdls.SetKeyRequest\x1a\x16.google.protobuf.Empty\"5\x8a\x92\x03\x31\x12)/api/sdls/{instance}/{linkName}/{spi}/key:\x04\x64\x61ta\x12\x85\x01\n\x06SetSpi\x12\".yamcs.protobuf.sdls.SetSpiRequest\x1a\x16.google.protobuf.Empty\"?\x8a\x92\x03;\x12*/api/sdls/{instance}/{linkName}/{vcId}/spi:\x04\x62odyj\x07Set SPI\x12\x89\x01\n\x07SetSpis\x12#.yamcs.protobuf.sdls.SetSpisRequest\x1a\x16.google.protobuf.Empty\"A\x8a\x92\x03=\x12+/api/sdls/{instance}/{linkName}/{vcId}/spis:\x04\x62odyj\x08Set SPIs\x1a\x0c\x82\x80\x01\x04SDLS\xd0\x80\x01\x01\x42!\n\x12org.yamcs.protobufB\tSdlsProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_SETSPIREQUEST = _descriptor.Descriptor(
  name='SetSpiRequest',
  full_name='yamcs.protobuf.sdls.SetSpiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.SetSpiRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.SetSpiRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vcId', full_name='yamcs.protobuf.sdls.SetSpiRequest.vcId', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='yamcs.protobuf.sdls.SetSpiRequest.body', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=258,
)


_SETSPIREQUESTBODY = _descriptor.Descriptor(
  name='SetSpiRequestBody',
  full_name='yamcs.protobuf.sdls.SetSpiRequestBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spi', full_name='yamcs.protobuf.sdls.SetSpiRequestBody.spi', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=292,
)


_SETSPISREQUEST = _descriptor.Descriptor(
  name='SetSpisRequest',
  full_name='yamcs.protobuf.sdls.SetSpisRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.SetSpisRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.SetSpisRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vcId', full_name='yamcs.protobuf.sdls.SetSpisRequest.vcId', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='yamcs.protobuf.sdls.SetSpisRequest.body', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=415,
)


_SETSPISREQUESTBODY = _descriptor.Descriptor(
  name='SetSpisRequestBody',
  full_name='yamcs.protobuf.sdls.SetSpisRequestBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spis', full_name='yamcs.protobuf.sdls.SetSpisRequestBody.spis', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=451,
)


_GETSEQCTRREQUEST = _descriptor.Descriptor(
  name='GetSeqCtrRequest',
  full_name='yamcs.protobuf.sdls.GetSeqCtrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.GetSeqCtrRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.GetSeqCtrRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spi', full_name='yamcs.protobuf.sdls.GetSeqCtrRequest.spi', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=520,
)


_GETSEQCTRRESPONSE = _descriptor.Descriptor(
  name='GetSeqCtrResponse',
  full_name='yamcs.protobuf.sdls.GetSeqCtrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.protobuf.sdls.GetSeqCtrResponse.seq', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=554,
)


_GETLINKSPISREQUEST = _descriptor.Descriptor(
  name='GetLinkSpisRequest',
  full_name='yamcs.protobuf.sdls.GetLinkSpisRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.GetLinkSpisRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.GetLinkSpisRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=612,
)


_GETLINKSPISRESPONSE = _descriptor.Descriptor(
  name='GetLinkSpisResponse',
  full_name='yamcs.protobuf.sdls.GetLinkSpisResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spis', full_name='yamcs.protobuf.sdls.GetLinkSpisResponse.spis', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=649,
)


_SETSEQCTRREQUEST = _descriptor.Descriptor(
  name='SetSeqCtrRequest',
  full_name='yamcs.protobuf.sdls.SetSeqCtrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.SetSeqCtrRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.SetSeqCtrRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spi', full_name='yamcs.protobuf.sdls.SetSeqCtrRequest.spi', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='yamcs.protobuf.sdls.SetSeqCtrRequest.body', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=775,
)


_SETSEQCTRREQUESTBODY = _descriptor.Descriptor(
  name='SetSeqCtrRequestBody',
  full_name='yamcs.protobuf.sdls.SetSeqCtrRequestBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.protobuf.sdls.SetSeqCtrRequestBody.seq', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=812,
)


_SETKEYREQUEST = _descriptor.Descriptor(
  name='SetKeyRequest',
  full_name='yamcs.protobuf.sdls.SetKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.SetKeyRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.SetKeyRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spi', full_name='yamcs.protobuf.sdls.SetKeyRequest.spi', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.sdls.SetKeyRequest.data', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=913,
)


_GETSAREQUEST = _descriptor.Descriptor(
  name='GetSaRequest',
  full_name='yamcs.protobuf.sdls.GetSaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.sdls.GetSaRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkName', full_name='yamcs.protobuf.sdls.GetSaRequest.linkName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spi', full_name='yamcs.protobuf.sdls.GetSaRequest.spi', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=915,
  serialized_end=978,
)


_GETSARESPONSE = _descriptor.Descriptor(
  name='GetSaResponse',
  full_name='yamcs.protobuf.sdls.GetSaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.protobuf.sdls.GetSaResponse.seq', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.sdls.GetSaResponse.algorithm', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyLen', full_name='yamcs.protobuf.sdls.GetSaResponse.keyLen', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdlsHeaderSize', full_name='yamcs.protobuf.sdls.GetSaResponse.sdlsHeaderSize', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdlsTrailerSize', full_name='yamcs.protobuf.sdls.GetSaResponse.sdlsTrailerSize', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sdlsOverhead', full_name='yamcs.protobuf.sdls.GetSaResponse.sdlsOverhead', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1115,
)

_SETSPIREQUEST.fields_by_name['body'].message_type = _SETSPIREQUESTBODY
_SETSPISREQUEST.fields_by_name['body'].message_type = _SETSPISREQUESTBODY
_SETSEQCTRREQUEST.fields_by_name['body'].message_type = _SETSEQCTRREQUESTBODY
_SETKEYREQUEST.fields_by_name['data'].message_type = yamcs_dot_api_dot_httpbody__pb2._HTTPBODY
DESCRIPTOR.message_types_by_name['SetSpiRequest'] = _SETSPIREQUEST
DESCRIPTOR.message_types_by_name['SetSpiRequestBody'] = _SETSPIREQUESTBODY
DESCRIPTOR.message_types_by_name['SetSpisRequest'] = _SETSPISREQUEST
DESCRIPTOR.message_types_by_name['SetSpisRequestBody'] = _SETSPISREQUESTBODY
DESCRIPTOR.message_types_by_name['GetSeqCtrRequest'] = _GETSEQCTRREQUEST
DESCRIPTOR.message_types_by_name['GetSeqCtrResponse'] = _GETSEQCTRRESPONSE
DESCRIPTOR.message_types_by_name['GetLinkSpisRequest'] = _GETLINKSPISREQUEST
DESCRIPTOR.message_types_by_name['GetLinkSpisResponse'] = _GETLINKSPISRESPONSE
DESCRIPTOR.message_types_by_name['SetSeqCtrRequest'] = _SETSEQCTRREQUEST
DESCRIPTOR.message_types_by_name['SetSeqCtrRequestBody'] = _SETSEQCTRREQUESTBODY
DESCRIPTOR.message_types_by_name['SetKeyRequest'] = _SETKEYREQUEST
DESCRIPTOR.message_types_by_name['GetSaRequest'] = _GETSAREQUEST
DESCRIPTOR.message_types_by_name['GetSaResponse'] = _GETSARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetSpiRequest = _reflection.GeneratedProtocolMessageType('SetSpiRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSPIREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSpiRequest)
  })
_sym_db.RegisterMessage(SetSpiRequest)

SetSpiRequestBody = _reflection.GeneratedProtocolMessageType('SetSpiRequestBody', (_message.Message,), {
  'DESCRIPTOR' : _SETSPIREQUESTBODY,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSpiRequestBody)
  })
_sym_db.RegisterMessage(SetSpiRequestBody)

SetSpisRequest = _reflection.GeneratedProtocolMessageType('SetSpisRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSPISREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSpisRequest)
  })
_sym_db.RegisterMessage(SetSpisRequest)

SetSpisRequestBody = _reflection.GeneratedProtocolMessageType('SetSpisRequestBody', (_message.Message,), {
  'DESCRIPTOR' : _SETSPISREQUESTBODY,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSpisRequestBody)
  })
_sym_db.RegisterMessage(SetSpisRequestBody)

GetSeqCtrRequest = _reflection.GeneratedProtocolMessageType('GetSeqCtrRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSEQCTRREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetSeqCtrRequest)
  })
_sym_db.RegisterMessage(GetSeqCtrRequest)

GetSeqCtrResponse = _reflection.GeneratedProtocolMessageType('GetSeqCtrResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSEQCTRRESPONSE,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetSeqCtrResponse)
  })
_sym_db.RegisterMessage(GetSeqCtrResponse)

GetLinkSpisRequest = _reflection.GeneratedProtocolMessageType('GetLinkSpisRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKSPISREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetLinkSpisRequest)
  })
_sym_db.RegisterMessage(GetLinkSpisRequest)

GetLinkSpisResponse = _reflection.GeneratedProtocolMessageType('GetLinkSpisResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKSPISRESPONSE,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetLinkSpisResponse)
  })
_sym_db.RegisterMessage(GetLinkSpisResponse)

SetSeqCtrRequest = _reflection.GeneratedProtocolMessageType('SetSeqCtrRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSEQCTRREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSeqCtrRequest)
  })
_sym_db.RegisterMessage(SetSeqCtrRequest)

SetSeqCtrRequestBody = _reflection.GeneratedProtocolMessageType('SetSeqCtrRequestBody', (_message.Message,), {
  'DESCRIPTOR' : _SETSEQCTRREQUESTBODY,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetSeqCtrRequestBody)
  })
_sym_db.RegisterMessage(SetSeqCtrRequestBody)

SetKeyRequest = _reflection.GeneratedProtocolMessageType('SetKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKEYREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.SetKeyRequest)
  })
_sym_db.RegisterMessage(SetKeyRequest)

GetSaRequest = _reflection.GeneratedProtocolMessageType('GetSaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAREQUEST,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetSaRequest)
  })
_sym_db.RegisterMessage(GetSaRequest)

GetSaResponse = _reflection.GeneratedProtocolMessageType('GetSaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSARESPONSE,
  '__module__' : 'yamcs.protobuf.sdls.sdls_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.sdls.GetSaResponse)
  })
_sym_db.RegisterMessage(GetSaResponse)


DESCRIPTOR._options = None

_SDLSAPI = _descriptor.ServiceDescriptor(
  name='SdlsApi',
  full_name='yamcs.protobuf.sdls.SdlsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\200\001\004SDLS\320\200\001\001',
  serialized_start=1118,
  serialized_end=2103,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLinkSpis',
    full_name='yamcs.protobuf.sdls.SdlsApi.GetLinkSpis',
    index=0,
    containing_service=None,
    input_type=_GETLINKSPISREQUEST,
    output_type=_GETLINKSPISRESPONSE,
    serialized_options=b'\212\222\0030\n\037/api/sdls/{instance}/{linkName}j\rGet link SPIs',
  ),
  _descriptor.MethodDescriptor(
    name='GetSa',
    full_name='yamcs.protobuf.sdls.SdlsApi.GetSa',
    index=1,
    containing_service=None,
    input_type=_GETSAREQUEST,
    output_type=_GETSARESPONSE,
    serialized_options=b'\212\222\003/\n%/api/sdls/{instance}/{linkName}/{spi}j\006Get SA',
  ),
  _descriptor.MethodDescriptor(
    name='GetSeqCtr',
    full_name='yamcs.protobuf.sdls.SdlsApi.GetSeqCtr',
    index=2,
    containing_service=None,
    input_type=_GETSEQCTRREQUEST,
    output_type=_GETSEQCTRRESPONSE,
    serialized_options=b'\212\222\003+\n)/api/sdls/{instance}/{linkName}/{spi}/seq',
  ),
  _descriptor.MethodDescriptor(
    name='SetSeqCtr',
    full_name='yamcs.protobuf.sdls.SdlsApi.SetSeqCtr',
    index=3,
    containing_service=None,
    input_type=_SETSEQCTRREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0031\022)/api/sdls/{instance}/{linkName}/{spi}/seq:\004body',
  ),
  _descriptor.MethodDescriptor(
    name='SetKey',
    full_name='yamcs.protobuf.sdls.SdlsApi.SetKey',
    index=4,
    containing_service=None,
    input_type=_SETKEYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\0031\022)/api/sdls/{instance}/{linkName}/{spi}/key:\004data',
  ),
  _descriptor.MethodDescriptor(
    name='SetSpi',
    full_name='yamcs.protobuf.sdls.SdlsApi.SetSpi',
    index=5,
    containing_service=None,
    input_type=_SETSPIREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003;\022*/api/sdls/{instance}/{linkName}/{vcId}/spi:\004bodyj\007Set SPI',
  ),
  _descriptor.MethodDescriptor(
    name='SetSpis',
    full_name='yamcs.protobuf.sdls.SdlsApi.SetSpis',
    index=6,
    containing_service=None,
    input_type=_SETSPISREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003=\022+/api/sdls/{instance}/{linkName}/{vcId}/spis:\004bodyj\010Set SPIs',
  ),
])
_sym_db.RegisterServiceDescriptor(_SDLSAPI)

DESCRIPTOR.services_by_name['SdlsApi'] = _SDLSAPI

# @@protoc_insertion_point(module_scope)



__all__ = [
    "ConnectionFailure",
    "NotFound",
    "TimeoutError",
    "Unauthorized",
    "YamcsError",
]


class YamcsError(Exception):
    """Base class for raised exceptions."""


class ConnectionFailure(YamcsError):
    """Yamcs is not or no longer available."""


class TimeoutError(YamcsError):
    """The operation exceeded the given deadline."""


class NotFound(YamcsError):
    """The resource was not found."""


class Unauthorized(YamcsError):
    """Unable to get access the resource."""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/alarms/alarms.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.events import events_pb2 as yamcs_dot_protobuf_dot_events_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/alarms/alarms.proto',
  package='yamcs.protobuf.alarms',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\013AlarmsProtoP\001',
  serialized_pb=b'\n\"yamcs/protobuf/alarms/alarms.proto\x12\x15yamcs.protobuf.alarms\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\"yamcs/protobuf/events/events.proto\"z\n\x0f\x41\x63knowledgeInfo\x12\x16\n\x0e\x61\x63knowledgedBy\x18\x01 \x01(\t\x12\x1a\n\x12\x61\x63knowledgeMessage\x18\x02 \x01(\t\x12\x33\n\x0f\x61\x63knowledgeTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9c\x01\n\nShelveInfo\x12\x11\n\tshelvedBy\x18\x01 \x01(\t\x12\x15\n\rshelveMessage\x18\x02 \x01(\t\x12.\n\nshelveTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10shelveExpiration\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"c\n\tClearInfo\x12\x11\n\tclearedBy\x18\x01 \x01(\t\x12-\n\tclearTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63learMessage\x18\x03 \x01(\t\"\x98\x06\n\tAlarmData\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .yamcs.protobuf.alarms.AlarmType\x12/\n\x0btriggerTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x02id\x18\x03 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x0e\n\x06seqNum\x18\x04 \x01(\r\x12\x36\n\x08severity\x18\x05 \x01(\x0e\x32$.yamcs.protobuf.alarms.AlarmSeverity\x12\x12\n\nviolations\x18\x06 \x01(\r\x12\r\n\x05\x63ount\x18\x07 \x01(\r\x12?\n\x0f\x61\x63knowledgeInfo\x18\x08 \x01(\x0b\x32&.yamcs.protobuf.alarms.AcknowledgeInfo\x12\x46\n\x10notificationType\x18\t \x01(\x0e\x32,.yamcs.protobuf.alarms.AlarmNotificationType\x12\x42\n\x0fparameterDetail\x18\n \x01(\x0b\x32).yamcs.protobuf.alarms.ParameterAlarmData\x12:\n\x0b\x65ventDetail\x18\x0b \x01(\x0b\x32%.yamcs.protobuf.alarms.EventAlarmData\x12\x10\n\x08latching\x18\x0c \x01(\x08\x12\x11\n\tprocessOK\x18\r \x01(\x08\x12\x11\n\ttriggered\x18\x0e \x01(\x08\x12\x14\n\x0c\x61\x63knowledged\x18\x0f \x01(\x08\x12\x35\n\nshelveInfo\x18\x10 \x01(\x0b\x32!.yamcs.protobuf.alarms.ShelveInfo\x12\x33\n\tclearInfo\x18\x11 \x01(\x0b\x32 .yamcs.protobuf.alarms.ClearInfo\x12.\n\nupdateTime\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08readonly\x18\x13 \x01(\x08\x12\x0f\n\x07pending\x18\x14 \x01(\x08\"\x84\x02\n\x12ParameterAlarmData\x12;\n\x0ctriggerValue\x18\x01 \x01(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12>\n\x0fmostSevereValue\x18\x02 \x01(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12;\n\x0c\x63urrentValue\x18\x03 \x01(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x34\n\tparameter\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\"\xaf\x01\n\x0e\x45ventAlarmData\x12\x32\n\x0ctriggerEvent\x18\x01 \x01(\x0b\x32\x1c.yamcs.protobuf.events.Event\x12\x35\n\x0fmostSevereEvent\x18\x02 \x01(\x0b\x32\x1c.yamcs.protobuf.events.Event\x12\x32\n\x0c\x63urrentEvent\x18\x03 \x01(\x0b\x32\x1c.yamcs.protobuf.events.Event*\xc3\x01\n\x15\x41larmNotificationType\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\r\n\tTRIGGERED\x10\x02\x12\x16\n\x12SEVERITY_INCREASED\x10\x03\x12\x11\n\rVALUE_UPDATED\x10\x04\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x05\x12\x0b\n\x07\x43LEARED\x10\x06\x12\x07\n\x03RTN\x10\x07\x12\x0b\n\x07SHELVED\x10\x08\x12\r\n\tUNSHELVED\x10\t\x12\t\n\x05RESET\x10\n\x12\x15\n\x11TRIGGERED_PENDING\x10\x0b*%\n\tAlarmType\x12\r\n\tPARAMETER\x10\x01\x12\t\n\x05\x45VENT\x10\x02*O\n\rAlarmSeverity\x12\t\n\x05WATCH\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\x0c\n\x08\x44ISTRESS\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x12\n\n\x06SEVERE\x10\x05\x42#\n\x12org.yamcs.protobufB\x0b\x41larmsProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_events_dot_events__pb2.DESCRIPTOR,])

_ALARMNOTIFICATIONTYPE = _descriptor.EnumDescriptor(
  name='AlarmNotificationType',
  full_name='yamcs.protobuf.alarms.AlarmNotificationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGERED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_INCREASED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_UPDATED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACKNOWLEDGED', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEARED', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTN', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHELVED', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSHELVED', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGERED_PENDING', index=10, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1845,
  serialized_end=2040,
)
_sym_db.RegisterEnumDescriptor(_ALARMNOTIFICATIONTYPE)

AlarmNotificationType = enum_type_wrapper.EnumTypeWrapper(_ALARMNOTIFICATIONTYPE)
_ALARMTYPE = _descriptor.EnumDescriptor(
  name='AlarmType',
  full_name='yamcs.protobuf.alarms.AlarmType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARAMETER', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2042,
  serialized_end=2079,
)
_sym_db.RegisterEnumDescriptor(_ALARMTYPE)

AlarmType = enum_type_wrapper.EnumTypeWrapper(_ALARMTYPE)
_ALARMSEVERITY = _descriptor.EnumDescriptor(
  name='AlarmSeverity',
  full_name='yamcs.protobuf.alarms.AlarmSeverity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WATCH', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTRESS', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2081,
  serialized_end=2160,
)
_sym_db.RegisterEnumDescriptor(_ALARMSEVERITY)

AlarmSeverity = enum_type_wrapper.EnumTypeWrapper(_ALARMSEVERITY)
ACTIVE = 1
TRIGGERED = 2
SEVERITY_INCREASED = 3
VALUE_UPDATED = 4
ACKNOWLEDGED = 5
CLEARED = 6
RTN = 7
SHELVED = 8
UNSHELVED = 9
RESET = 10
TRIGGERED_PENDING = 11
PARAMETER = 1
EVENT = 2
WATCH = 1
WARNING = 2
DISTRESS = 3
CRITICAL = 4
SEVERE = 5



_ACKNOWLEDGEINFO = _descriptor.Descriptor(
  name='AcknowledgeInfo',
  full_name='yamcs.protobuf.alarms.AcknowledgeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acknowledgedBy', full_name='yamcs.protobuf.alarms.AcknowledgeInfo.acknowledgedBy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledgeMessage', full_name='yamcs.protobuf.alarms.AcknowledgeInfo.acknowledgeMessage', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledgeTime', full_name='yamcs.protobuf.alarms.AcknowledgeInfo.acknowledgeTime', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=346,
)


_SHELVEINFO = _descriptor.Descriptor(
  name='ShelveInfo',
  full_name='yamcs.protobuf.alarms.ShelveInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shelvedBy', full_name='yamcs.protobuf.alarms.ShelveInfo.shelvedBy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shelveMessage', full_name='yamcs.protobuf.alarms.ShelveInfo.shelveMessage', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shelveTime', full_name='yamcs.protobuf.alarms.ShelveInfo.shelveTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shelveExpiration', full_name='yamcs.protobuf.alarms.ShelveInfo.shelveExpiration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=505,
)


_CLEARINFO = _descriptor.Descriptor(
  name='ClearInfo',
  full_name='yamcs.protobuf.alarms.ClearInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clearedBy', full_name='yamcs.protobuf.alarms.ClearInfo.clearedBy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clearTime', full_name='yamcs.protobuf.alarms.ClearInfo.clearTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clearMessage', full_name='yamcs.protobuf.alarms.ClearInfo.clearMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=606,
)


_ALARMDATA = _descriptor.Descriptor(
  name='AlarmData',
  full_name='yamcs.protobuf.alarms.AlarmData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.alarms.AlarmData.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerTime', full_name='yamcs.protobuf.alarms.AlarmData.triggerTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.alarms.AlarmData.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNum', full_name='yamcs.protobuf.alarms.AlarmData.seqNum', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='yamcs.protobuf.alarms.AlarmData.severity', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='violations', full_name='yamcs.protobuf.alarms.AlarmData.violations', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.alarms.AlarmData.count', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledgeInfo', full_name='yamcs.protobuf.alarms.AlarmData.acknowledgeInfo', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notificationType', full_name='yamcs.protobuf.alarms.AlarmData.notificationType', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterDetail', full_name='yamcs.protobuf.alarms.AlarmData.parameterDetail', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventDetail', full_name='yamcs.protobuf.alarms.AlarmData.eventDetail', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latching', full_name='yamcs.protobuf.alarms.AlarmData.latching', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processOK', full_name='yamcs.protobuf.alarms.AlarmData.processOK', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggered', full_name='yamcs.protobuf.alarms.AlarmData.triggered', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledged', full_name='yamcs.protobuf.alarms.AlarmData.acknowledged', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shelveInfo', full_name='yamcs.protobuf.alarms.AlarmData.shelveInfo', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clearInfo', full_name='yamcs.protobuf.alarms.AlarmData.clearInfo', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='yamcs.protobuf.alarms.AlarmData.updateTime', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readonly', full_name='yamcs.protobuf.alarms.AlarmData.readonly', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending', full_name='yamcs.protobuf.alarms.AlarmData.pending', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=1401,
)


_PARAMETERALARMDATA = _descriptor.Descriptor(
  name='ParameterAlarmData',
  full_name='yamcs.protobuf.alarms.ParameterAlarmData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='triggerValue', full_name='yamcs.protobuf.alarms.ParameterAlarmData.triggerValue', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mostSevereValue', full_name='yamcs.protobuf.alarms.ParameterAlarmData.mostSevereValue', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentValue', full_name='yamcs.protobuf.alarms.ParameterAlarmData.currentValue', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.alarms.ParameterAlarmData.parameter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1664,
)


_EVENTALARMDATA = _descriptor.Descriptor(
  name='EventAlarmData',
  full_name='yamcs.protobuf.alarms.EventAlarmData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='triggerEvent', full_name='yamcs.protobuf.alarms.EventAlarmData.triggerEvent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mostSevereEvent', full_name='yamcs.protobuf.alarms.EventAlarmData.mostSevereEvent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentEvent', full_name='yamcs.protobuf.alarms.EventAlarmData.currentEvent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1842,
)

_ACKNOWLEDGEINFO.fields_by_name['acknowledgeTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SHELVEINFO.fields_by_name['shelveTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SHELVEINFO.fields_by_name['shelveExpiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLEARINFO.fields_by_name['clearTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARMDATA.fields_by_name['type'].enum_type = _ALARMTYPE
_ALARMDATA.fields_by_name['triggerTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARMDATA.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_ALARMDATA.fields_by_name['severity'].enum_type = _ALARMSEVERITY
_ALARMDATA.fields_by_name['acknowledgeInfo'].message_type = _ACKNOWLEDGEINFO
_ALARMDATA.fields_by_name['notificationType'].enum_type = _ALARMNOTIFICATIONTYPE
_ALARMDATA.fields_by_name['parameterDetail'].message_type = _PARAMETERALARMDATA
_ALARMDATA.fields_by_name['eventDetail'].message_type = _EVENTALARMDATA
_ALARMDATA.fields_by_name['shelveInfo'].message_type = _SHELVEINFO
_ALARMDATA.fields_by_name['clearInfo'].message_type = _CLEARINFO
_ALARMDATA.fields_by_name['updateTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARAMETERALARMDATA.fields_by_name['triggerValue'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_PARAMETERALARMDATA.fields_by_name['mostSevereValue'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_PARAMETERALARMDATA.fields_by_name['currentValue'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_PARAMETERALARMDATA.fields_by_name['parameter'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._PARAMETERINFO
_EVENTALARMDATA.fields_by_name['triggerEvent'].message_type = yamcs_dot_protobuf_dot_events_dot_events__pb2._EVENT
_EVENTALARMDATA.fields_by_name['mostSevereEvent'].message_type = yamcs_dot_protobuf_dot_events_dot_events__pb2._EVENT
_EVENTALARMDATA.fields_by_name['currentEvent'].message_type = yamcs_dot_protobuf_dot_events_dot_events__pb2._EVENT
DESCRIPTOR.message_types_by_name['AcknowledgeInfo'] = _ACKNOWLEDGEINFO
DESCRIPTOR.message_types_by_name['ShelveInfo'] = _SHELVEINFO
DESCRIPTOR.message_types_by_name['ClearInfo'] = _CLEARINFO
DESCRIPTOR.message_types_by_name['AlarmData'] = _ALARMDATA
DESCRIPTOR.message_types_by_name['ParameterAlarmData'] = _PARAMETERALARMDATA
DESCRIPTOR.message_types_by_name['EventAlarmData'] = _EVENTALARMDATA
DESCRIPTOR.enum_types_by_name['AlarmNotificationType'] = _ALARMNOTIFICATIONTYPE
DESCRIPTOR.enum_types_by_name['AlarmType'] = _ALARMTYPE
DESCRIPTOR.enum_types_by_name['AlarmSeverity'] = _ALARMSEVERITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AcknowledgeInfo = _reflection.GeneratedProtocolMessageType('AcknowledgeInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACKNOWLEDGEINFO,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.AcknowledgeInfo)
  })
_sym_db.RegisterMessage(AcknowledgeInfo)

ShelveInfo = _reflection.GeneratedProtocolMessageType('ShelveInfo', (_message.Message,), {
  'DESCRIPTOR' : _SHELVEINFO,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ShelveInfo)
  })
_sym_db.RegisterMessage(ShelveInfo)

ClearInfo = _reflection.GeneratedProtocolMessageType('ClearInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLEARINFO,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ClearInfo)
  })
_sym_db.RegisterMessage(ClearInfo)

AlarmData = _reflection.GeneratedProtocolMessageType('AlarmData', (_message.Message,), {
  'DESCRIPTOR' : _ALARMDATA,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.AlarmData)
  })
_sym_db.RegisterMessage(AlarmData)

ParameterAlarmData = _reflection.GeneratedProtocolMessageType('ParameterAlarmData', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERALARMDATA,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.ParameterAlarmData)
  })
_sym_db.RegisterMessage(ParameterAlarmData)

EventAlarmData = _reflection.GeneratedProtocolMessageType('EventAlarmData', (_message.Message,), {
  'DESCRIPTOR' : _EVENTALARMDATA,
  '__module__' : 'yamcs.protobuf.alarms.alarms_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.alarms.EventAlarmData)
  })
_sym_db.RegisterMessage(EventAlarmData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import warnings

warnings.warn(
    "The module 'yamcs.tmtc.client' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.tmtc.client import (  # noqa
    AlarmSubscription,
    CommandConnection,
    CommandHistorySubscription,
    ContainerSubscription,
    ParameterSubscription,
    ProcessorClient,
)
